@@ -12,9 +12,11 @@ CREATE TABLE build (
   deploy_dttm TIMESTAMP DEFAULT NULL,
   deploy_output_tx TEXT DEFAULT NULL,
   deploy_exit_status INTEGER DEFAULT NULL,
+  deploy_message TEXT DEFAULT NULL,
   revert_dttm TIMESTAMP DEFAULT NULL,
   revert_output_tx TEXT DEFAULT NULL,
   revert_exit_status INTEGER DEFAULT NULL,
+  revert_message TEXT DEFAULT NULL,
   create_dttm TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   update_dttm TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   delete_dttm TIMESTAMP DEFAULT NULL,
