@@ -61,6 +61,13 @@ def shell(cmd, cwd=None, env=None):
     stderr = stderr.decode('utf-8').strip()
     return (stdout, stderr, proc.returncode)
 
+def multi_shell(cmds, cwd=None, env=None):
+    """ These processes should all be started and non-blocking. Then caller can use communicate(), wait(), call() as needed. """
+    procs = []
+    for cmd in cmds:
+        procs.append(subprocess.Popen(shlex.split(cmd), stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False, cwd=cwd, env=env))
+    return procs
+
 def force_int(string):
     if type(string) in (int, int): return int(string)
     int_re = re.compile('^.*?(\d+).*?$')
@@ -774,6 +781,22 @@ def timer_stop(obj, timer_name):
         obj._timers[stop_name] = time.time()
         obj._timers[exec_name] = obj._timers[stop_name] - obj._timers[start_name]
 
+def timer_log(obj, timer_name):
+    if not obj:
+        return {}
+    exec_name = '_%s_exec_s' % timer_name
+    logging.error("%s  %.3f ms" % (timer_name, 1000 * obj._timers[exec_name]))
+
+def timer_reset(obj, timer_name):
+    if not obj:
+        return {}
+    start_name = '_%s_start_ts' % timer_name
+    stop_name = '_%s_stop_ts' % timer_name
+    exec_name = '_%s_exec_s' % timer_name
+    del obj._timers[start_name]
+    del obj._timers[stop_name]
+    del obj._timers[exec_name]
+
 def incr_start(obj, timer_name):
     if not obj:
         return {}
